/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* init.c
 * Copyright (C) 2005 Hiroyuki Ikezoe <poincare@ikezoe.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glib/gi18n.h>
#include <gconf/gconf-client.h>
#include <stdlib.h>

#include "gsynaptics.h"
#include "gsynaptics-conf.h"

static GConfClient *gconf = NULL;

static void
setup_user_value (GSynaptics *synaptics)
{
	gboolean b_value;
	gint i_value;
    GConfValue *gval = NULL;

	if (!gconf_client_dir_exists (gconf, DIRNAME, NULL))
		return;

	/* touchpad on/off */	
	gval = gconf_client_get (gconf, OFF_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_BOOL) {
			b_value = gconf_value_get_bool(gval);
			g_synaptics_set_enabled (synaptics, b_value ? 1 : 0);
		}
		gconf_value_free(gval);
	}
	
	/* vertical scroll delta */
	gval = gconf_client_get (gconf, VERTSCROLLDELTA_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_vertical_scroll_delta (synaptics, i_value);
		}
		gconf_value_free(gval);
	}
	
	/* horizontal scroll delta */
	gval = gconf_client_get (gconf, HORIZSCROLLDELTA_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_horizontal_scroll_delta (synaptics, i_value);
		}
		gconf_value_free(gval);
	}
	
	/* circular scroll */
	gval = gconf_client_get (gconf, CIRCSCROLLDELTA_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_circular_scroll_delta (synaptics, i_value);
		}
		gconf_value_free(gval);
	}
	gval = gconf_client_get (gconf, CIRCULARSCROLLING_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_BOOL) {
			b_value = gconf_value_get_bool(gval);
			g_synaptics_set_circular_scroll_enabled (synaptics, b_value);
		}
		gconf_value_free(gval);
	}
	/* the trigger of circular scrolling */
	gval = gconf_client_get (gconf, CIRCSCROLLTRIGGER_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_circular_scroll_trigger (synaptics, i_value);
		}
		gconf_value_free(gval);
	}
	
	
	/* tapping time */
	gval = gconf_client_get (gconf, MAXTAPTIME_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_tap_time (synaptics, i_value);
		}
		gconf_value_free(gval);
	}
	
	/* fast taps */
	gval = gconf_client_get (gconf, FASTTAPS_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_BOOL) {
			b_value = gconf_value_get_bool(gval);
			g_synaptics_set_fast_taps (synaptics, b_value);
		}
		gconf_value_free(gval);
	}
	
	/* sensitivity */
	gval = gconf_client_get (gconf, SENSITIVITY_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_sensitivity (synaptics, i_value);
		}
		gconf_value_free(gval);
	}

	/* coasting */
	gval = gconf_client_get (gconf, COASTENABLE_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_BOOL) {
			b_value = gconf_value_get_bool(gval);
			g_synaptics_set_coasting_enabled (synaptics, b_value);
		}
		gconf_value_free(gval);
	}
	
	/* edge motion */
	gval = gconf_client_get (gconf, EDGEMOTIONUSEALWAYS_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_BOOL) {
			b_value = gconf_value_get_bool(gval);
			g_synaptics_set_edge_motion_enabled (synaptics, b_value);
		}
		gconf_value_free(gval);
	}

	/* min speed */
	gval = gconf_client_get (gconf, MINSPEED_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_min_speed (synaptics, i_value);
		}
		gconf_value_free(gval);
	}

	/* max speed */
	gval = gconf_client_get (gconf, MAXSPEED_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_max_speed (synaptics, i_value);
		}
		gconf_value_free(gval);
	}

	/* accel factor */
	gval = gconf_client_get (gconf, ACCELFACTOR_KEY, NULL);
	if (gval != NULL) {
		if (gval->type == GCONF_VALUE_INT) {
			i_value = gconf_value_get_int(gval);
			g_synaptics_set_accel_factor (synaptics, i_value);
		}
		gconf_value_free(gval);
	}

}

int
main (int argc, char **argv)
{
	GSynaptics *synaptics;

	bindtextdomain (GETTEXT_PACKAGE, GSYNAPTICS_LOCALEDIR);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);

	gtk_init (&argc, &argv);

	synaptics = g_synaptics_new ();

	if (!g_synaptics_is_available(synaptics))
	{
		g_object_unref (synaptics);
		g_printerr (_("GSynaptics couldn't initialize.\n"
			      "You have to set 'SHMConfig' 'true' in xorg.conf or XFree86.conf to use GSynaptics\n"));
		exit(1);
	}

	gconf = gconf_client_get_default ();

	/* set user value */
	setup_user_value (synaptics);

	g_object_unref (synaptics);

	g_object_unref (gconf);

	return 0;
}
